Plone intranet

#

# Public bodies reform

Delete Copy Share Toggle extra metadata

Government has announced its intention to close or take out of public ownership 192 arm’s-length bodies (ALBs) and to merge a further 118. The process of reorganising ALBs places information at risk. These risks may be different to those encountered during ‘business as usual’, and will require careful management.

Making arrangements for the transfer of information, records and knowledge is a key part of any Machinery of Government change. It must be properly planned and adequately resourced. Failure to transfer information and knowledge effectively can prevent you operating legally, transparently and accountably. It can also cause inefficiencies and lead to substantial additional cost.

Leave a comment

Attach a file (or create a picture)

No attachments selected.

Mention people Add tags

## Share

Add a comment to your share…

#### Public bodies reform

Making arrangements for the transfer of information, records and knowledge is a key part of any Machinery of Government change.

Mention people Add tags